# Praison AI

Praison AI, leveraging both AutoGen and CrewAI or any other agent framework, represents a low-code, centralised framework designed to simplify the creation and orchestration of multi-agent systems for various LLM applications, emphasizing ease of use, customization, and human-agent interaction.

## Installation

```bash
pip install praisonai
```

## Run

```bash
praisonai
```

## Test
    
```bash
python -m unittest tests.test 
```